clear all;

draws = 1000000;
statshere = [11 15]';
numstats = length(statshere);

resultfile = 'results\resultreoccplus.mat';%Plus
graphfile  = 'results\graphreoccplus';%Plus
load(resultfile)

varname = 'Occupation';

metrics = cell(numstats,1);
metrics{1} = 'Chi-squared statistic';
metrics{2} = 'Sum of Group Payoffs';

numdecimalplaces=3;
[numvills numvars] = size(output);
maxstats = length(stats);

for j=1:numstats
    statsj = statshere(j);
    if ~stats(statsj)
        error('Don''t have this one')
    end
    thisstat = sum(stats(1:statshere(j)))
    
    missindces = find(isnan(output(:,numdata*(thisstat-1)+2)));
    for k=3:numdata
        if missindces~= find(isnan(output(:,numdata*(thisstat-1)+k)))
            error('Something wrong.');
        end
    end
    tempoutput = output(:,numdata*(thisstat-1)+2:numdata*(thisstat-1)+numdata);
    tempoutput(missindces,:)=[];

    pctls = tempoutput(:,1);
    pcteq = tempoutput(:,2);
    pctgt = tempoutput(:,3);
    
    numvalid = length(pctls);
    
    weights(:,1) = ones(numvalid,1)/numvalid;
    if stats(j)>1
        fractcombs = tempoutput(:,4);
        weights(:,2) = fractcombs/nansum(fractcombs);
    end

    for styl =1:stats(statsj)
        wts = weights(:,styl);
    
        pctile = pctls + pcteq/2;
        meanpct = nansum(pctile.*wts);

        [cdf keypoints] = getcdf(pctls,1-pctgt,wts);

        mdnindex  = find(round(cdf),1);
        medn   = keypoints(mdnindex-1) + (keypoints(mdnindex)-keypoints(mdnindex-1)) ... 
            * (1/2-cdf(mdnindex-1))/(cdf(mdnindex)-cdf(mdnindex-1));

        rulen = [1:numvalid]'  /numvalid;
        rulep = [0:numvalid-1]'/numvalid;

        ksstatpu = max(keypoints-cdf);
        ksstatnu = max(cdf-keypoints);
        fakedata = max(rulep, ksstatpu);
        [junk kspvalposu ksstatpuck] = kstest(fakedata, 'CDF', [fakedata fakedata], 'Tail', 'smaller')
        if abs(ksstatpu-ksstatpuck) > 1/10^10
            error('KS test off.')
        end
        fakedata = min(rulen, 1-ksstatnu);
        [junk kspvalnegu ksstatnuck] = kstest(fakedata, 'CDF', [fakedata fakedata], 'Tail', 'larger')
        if abs(ksstatnu-ksstatnuck) > 1/10^10
            error('KS test off.')
        end

        randmat = rand(numvalid,draws);
        warning off;
        kspvalp = zeros(draws,1)/0;
        kspvaln = zeros(draws,1)/0;
        warning on;
        for z=1:draws
            thisdraw = pctls + randmat(:,z).*pcteq;
            thiscdf = sortrows([thisdraw wts],1);
            thiscdf(:,2) = cumsum(thiscdf(:,2));
            ksstatp = max(thiscdf(:,1)- [0; thiscdf(1:numvalid-1,2)]);
            ksstatn = max(thiscdf(:,2)-thiscdf(:,1));
            
            fakedata = max(rulep, ksstatp);
            [junk kspvalp(z) ksstatpck] = kstest(fakedata, 'CDF', [fakedata fakedata], 'Tail', 'smaller');
            if abs(ksstatp-ksstatpck) > 1/10^10
                error('KS test off.')
            end
            fakedata = min(rulen, 1-ksstatn);
            [junk kspvaln(z) ksstatnck] = kstest(fakedata, 'CDF', [fakedata fakedata], 'Tail', 'larger');
            if abs(ksstatn-ksstatnck) > 1/10^10
                error('KS test off.')
            end
            
        end
        kspvalpavg = mean(kspvalp)
        kspvalnavg = mean(kspvaln)
        
        subplot(1,numstats,j)
        plot([0; keypoints;1],[0; cdf; 1])
        hold on
        plot([0 1], [0 1]','--')
        
        %%% This is part of the "plus" -- finding and graphing a cdf
        %%% corresponding to maximally & minimally homogeneous matching.
        pctmin = tempoutput(:,8);
        pctmax = tempoutput(:,9);
        [mincdf minkeypoints] = getcdf(zeros(length(pctmin),1),pctmin,wts);
        [maxcdf maxkeypoints] = getcdf(1-pctmax,ones(length(pctmax),1),wts);
        plot([0; minkeypoints;1],[0; mincdf; 1],'-.')
        %plot([0; maxkeypoints;1],[0; maxcdf; 1],'-.')
        %%% Done with these extra cdfs
        
        hold off
        axis([0 1 0 1])
        xticks([0 0.2 0.4 0.6 0.8 1])
        yticks([0 0.2 0.4 0.6 0.8 1])

        if j==1
            text(0.25,1.11,'CDF of matching percentiles for Occupation','FontName','Arial','FontSize',13);
        end
        title(strcat('Metric=',metrics{j}),'FontName','Arial','FontSize',10);

        meanpctile = strdecim(meanpct,numdecimalplaces);
        mednpctile = strdecim(medn,numdecimalplaces);
        meadnstru  = ['Mean: ' meanpctile ',  Median: ' mednpctile];
        t2 = text(0.15,0.05,meadnstru);

        pvalpu = strdecimceil(kspvalpavg,numdecimalplaces+1);
        pvalstru = 'KS one-sided p-values:';
        t3 = text(0.31,0.17,pvalstru);
        pvalsboth = ['   (+) ' strdecim(kspvalpavg,numdecimalplaces) ' ,  (-) ' strdecim(kspvalnavg,numdecimalplaces)];
        t4 = text(0.31,0.12,pvalsboth);
        t5 = text(0.31,0.23,['N (Villages) = ' num2str(numvalid)]);

        t = [t2 t3 t4 t5];
        set(t,'FontSize',9,'FontName','Arial');
        
    end
    
end

thisgraphfile = [graphfile '.eps'];
eval(['!del ' thisgraphfile]);
print('-deps2', thisgraphfile);