function c=computecatineq(data,grupnums,stats,catgs)
% decompose inequality for non-ordered categorical variables
% categories can include fractions
% for more on formulas, see scanned analytical work

numgroups = length(grupnums);
cumnumgps = cumsum(grupnums);
if numgroups<2 || numgroups>3
    error('Error in geteq3.m');
end

numcatgs = length(catgs);

Nkgsq = zeros(numgroups,1);
NkgsqdNk = zeros(numgroups,1);
Nabsdif = zeros(numgroups,1);
Nk = zeros(numcatgs,1);
for k=1:numcatgs
    Nk(k) = sum(sort(data(:,k)));
end

last = 0;
for g=1:numgroups
    frst = last+1;
    last = cumnumgps(g);
    thisgroup = sortrows(data(frst:last,:));
    for k=1:numcatgs
        thiski = thisgroup(:,k);
        thisNkgsq = (sum(thiski))^2;
        Nkgsq(g) = Nkgsq(g) + thisNkgsq - thiski'*thiski;
        if Nk(k)
            NkgsqdNk(g) = NkgsqdNk(g) + thisNkgsq/Nk(k);
        end
        if stats(15)
            thiskmat = repmat(thiski,1,grupnums(g));
            Nabsdif(g) = Nabsdif(g) - sum(sum( abs(thiskmat-thiskmat') ));
        end
    end
end

c = [];

if stats(8)
%{
The percent of fractionalization attributable to the between component 
depends only on the following, as can be shown, for fixed group sizes and 
total population.  
Also, directly interpretable as total within-group links (including OR 
excluding self-links, it only depends on this for fixed group sizes) with 
the same value, or fraction of within-group links with the same value
(again, given fixed group sizes).
%}    
    c = [c; sum( Nkgsq )];
end
if stats(9)
%{
This is analogous to picking a guy at random and asking what fraction of
his group is the same, excluding himself (if including himself, do not
subtract 1). Thus it is the average fraction of within-group links 
(excluding own-links) that have the same value, across all individuals in
the village.
%}
    c = [c; sum( Nkgsq./(grupnums-1) )];
end
if stats(10)
%{
This is analogous to picking a group at random, then a guy at random, then
asking what fraction of his group is the same, excluding himself (if 
including himself, do not subtract 1). Thus it is the group-average of the
individual-average fraction of within-group links (excluding own-links) 
that have the same value, across all individuals in the group.
%}
    c = [c; sum( Nkgsq./(grupnums.*(grupnums-1)) )];
end
if stats(11)
% This is for the chi-sq test statistic.
    c = [c; sum( NkgsqdNk./grupnums )];
end 
if length(stats)>=15 && stats(15)
% This is for the taxicab distance metric.
    c = [c; sum( Nabsdif./(grupnums-1) )];
end 